package com.huimv.admin.system.service;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.IService;
import com.huimv.admin.system.entity.User;
import com.huimv.common.utils.Result;

import java.util.List;

/**
 * <p>
 *  服务类
 * </p>
 *
 * @author astupidcoder
 * @since 2021-09-09
 */
public interface IUserService extends IService<User> {


    JSONObject findUserAccount(String searchStr, int pageNum, int pageSize);


//    List<UserAndAccountGroup> yxxList(String searchStr, int pageNum, int pageSize);

    Result addUser(User user);

    Result updateUser(User user);

    Result removeUser(List<Integer> userIds);
}
