package com.huimv.eartag2.admin.controller;


import com.alibaba.fastjson.JSONObject;
import com.huimv.eartag2.admin.service.IUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Map;

@RestController
@RequestMapping("/user")
public class SysUserController {
    @Autowired
    private IUserService iUserService;

//    @PostMapping("/add")
//    public Result addUser(@RequestBody User user){
//        return  iUserService.addUser(user);
//    }
//
//    @PostMapping("/edit")
//    public Result updateUser(@RequestBody User user){
//        return iUserService.updateUser(user);
//    }
//
//    @RequestMapping("/remove")
//    public Result removeUser(@RequestParam("userIds") List<Integer> userIds) {
//
//        return iUserService.removeUser(userIds);
//    }



    @PostMapping("/list")
    public JSONObject listUser(@RequestBody Map map) {
        System.out.println();
        int pageNum = (Integer)map.get("pageNum");
        int pageSize = (Integer)map.get("pageSize");
        String searchStr = (String)map.get("searchStr");
        return iUserService.findUserAccount(searchStr,pageNum,pageSize);
    }

}
